==> owncloud_7.0.4+dfsg.orig.tar.bz2: owncloud/settings/l10n/sl.php <==
<?php
$TRANSLATIONS = array(
"Invalid value supplied for %s" => "Navedena je napačna vrednost za %s",
"Saved" => "Shranjeno",
"test email settings" => "preizkusi nastavitve elektronske pošte",
"If you received this email, the settings seem to be correct." => "Če ste prejeli to sporočilo, so nastavitve pravilne.",
"A problem occurred while sending the e-mail. Please revisit your settings." => "Prišlo je do napake med pošiljanjem sporočila na elektronski naslov. Spremeniti je treba nastavitve.",
"Email sent" => "Elektronska pošta je poslana",
"Send mode" => "Način pošiljanja",
"Encryption" => "Šifriranje",
"Authentication method" => "Način overitve",
"Unable to load list from App Store" => "Ni mogoče naložiti seznama iz programskega središča",
"Authentication error" => "Napaka med overjanjem",
"Your full name has been changed." => "Vaše polno ime je spremenjeno.",
"Unable to change full name" => "Ni mogoče spremeniti polnega imena",
"Group already exists" => "Skupina že obstaja",
"Unable to add group" => "Skupine ni mogoče dodati",
"Files decrypted successfully" => "Datoteke so uspešno odšifrirane",
"Couldn't decrypt your files, please check your owncloud.log or ask your administrator" => "Datotek ni mogoče odšifrirati. Preverite dnevnik owncloud.log ali pa se posvetujte s skrbnikom.",
"Couldn't decrypt your files, check your password and try again" => "Datotek ni mogoče odšifrirati. Preverite geslo in poskusite znova.",
"Email saved" => "Elektronski naslov je shranjen",
"Invalid email" => "Neveljaven elektronski naslov",
"Unable to delete group" => "Skupine ni mogoče izbrisati",
"Unable to delete user" => "Uporabnika ni mogoče izbrisati",
"Language changed" => "Jezik je spremenjen",
"Invalid request" => "Neveljavna zahteva",
"Admins can't remove themself from the admin group" => "Skrbnikov ni mogoče odstraniti iz skupine skrbnikov (admin)",
"Unable to add user to group %s" => "Uporabnika ni mogoče dodati k skupini %s",
"Unable to remove user from group %s" => "Uporabnika ni mogoče odstraniti iz skupine %s",
"Couldn't update app." => "Programa ni mogoče posodobiti.",
"Wrong password" => "Napačno geslo",
"No user supplied" => "Ni navedenega uporabnika",
"Please provide an admin recovery password, otherwise all user data will be lost" => "Podati je treba skrbniško obnovitveno geslo, sicer bodo vsi uporabniški podatki izgubljeni.",
"Wrong admin recovery password. Please check the password and try again." => "Napačno navedeno skrbniško obnovitveno geslo. Preverite geslo in poskusite znova.",
"Back-end doesn't support password change, but the users encryption key was successfully updated." => "Hrbtišče programa ne podpira spreminjanja gesla, je pa uspešno posodobljeno uporabniško šifriranje.",
"Unable to change password" => "Ni mogoče spremeniti gesla",
"Sending..." => "Poteka pošiljanje ...",
"User Documentation" => "Uporabniška dokumentacija",
"Admin Documentation" => "Skrbniška dokumentacija",
"Update to {appversion}" => "Posodobi na {appversion}",
"Disable" => "Onemogoči",
"Enable" => "Omogoči",
"Please wait...." => "Počakajte ...",
"Error while disabling app" => "Napaka onemogočanja programa",
"Error while enabling app" => "Napaka omogočanja programa",
"Updating...." => "Poteka posodabljanje ...",
"Error while updating app" => "Prišlo je do napake med posodabljanjem programa.",
"Error" => "Napaka",
"Update" => "Posodobi",
"Updated" => "Posodobljeno",
"Uninstall" => "Odstrani namestitev",
"Select a profile picture" => "Izbor slike profila",
"Very weak password" => "Zelo šibko geslo",
"Weak password" => "Šibko geslo",
"So-so password" => "Slabo geslo",
"Good password" => "Dobro geslo",
"Strong password" => "Odlično geslo",
"Decrypting files... Please wait, this can take some time." => "Poteka odšifriranje datotek ... Opravilo je lahko dolgotrajno.",
"undo" => "razveljavi",
"Groups" => "Skupine",
"Group Admin" => "Skrbnik skupine",
"Delete" => "Izbriši",
"never" => "nikoli",
"add group" => "dodaj skupino",
"A valid username must be provided" => "Navedeno mora biti veljavno uporabniško ime",
"Error creating user" => "Napaka ustvarjanja uporabnika",
"A valid password must be provided" => "Navedeno mora biti veljavno geslo",
"Warning: Home directory for user \"{user}\" already exists" => "Opozorilo: osebna mapa uporabnika \"{user}\" že obstaja",
"__language_name__" => "Slovenščina",
"Everything (fatal issues, errors, warnings, info, debug)" => "Vse (podrobnosti, opozorila, hrošče, napake in usodne dogodke)",
"Info, warnings, errors and fatal issues" => "Podrobnosti, opozorila, napake in usodne dogodke",
"Warnings, errors and fatal issues" => "Opozorila, napake in usodne dogodke",
"Errors and fatal issues" => "Napake in usodne dogodke",
"Fatal issues only" => "Le usodne dogodke",
"None" => "Brez",
"Login" => "Prijava",
"Plain" => "Besedilno",
"NT LAN Manager" => "Upravljalnik NT LAN",
"SSL" => "SSL",
"TLS" => "TLS",
"Security Warning" => "Varnostno opozorilo",
"You are accessing %s via HTTP. We strongly suggest you configure your server to require using HTTPS instead." => "Dostop do %s poteka preko HTTP. Priporočljivo je nastaviti strežnik na privzeto uporabo varne povezave preko protokola HTTPS.",
"Your data directory and your files are probably accessible from the internet. The .htaccess file is not working. We strongly suggest that you configure your webserver in a way that the data directory is no longer accessible or you move the data directory outside the webserver document root." => "Vaša podatkovna mapa in datoteke so najverjetneje dosegljive preko interneta. Datoteka .htaccess ni ustrezno nastavljena. Priporočljivo je nastaviti spletni strežnik tako, da podatkovna mapa ni prosto dostopna. To je mogoče zagotoviti tudi tako, da je mapa premaknjena iz neustrezne korenske v podrejeno mapo .",
"Setup Warning" => "Opozorilo nastavitve",
"Your web server is not yet properly setup to allow files synchronization because the WebDAV interface seems to be broken." => "Spletni stražnik še ni ustrezno nastavljen in ne omogoča usklajevanja, saj je nastavitev WebDAV okvarjena.",
"Please double check the <a href=\"%s\">installation guides</a>." => "Preverite <a href=\"%s\">vodnike namestitve</a>.",
"Module 'fileinfo' missing" => "Manjka modul 'fileinfo'.",
"The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." => "Manjka modul PHP 'fileinfo'. Priporočljivo je omogočiti ta modul za popolno zaznavanje vrst MIME.",
"Your PHP version is outdated" => "Nameščena različica PHP je zastarela",
"Your PHP version is outdated. We strongly recommend to update to 5.3.8 or newer because older versions are known to be broken. It is possible that this installation is not working correctly." => "Nameščena različica PHP je zastarela. Priporočljivo je posodobiti namestitev na različico 5.3.8 ali novejše, saj starejše različice ne podpirajo vseh zmožnosti. Mogoče je, da namestitev ne deluje pravilno.",
"Locale not working" => "Jezikovne prilagoditve ne delujejo.",
"System locale can not be set to a one which supports UTF-8." => "Sistemskih jezikovnih nastavitev ni mogoče nastaviti na možnost, ki podpira nabor UTF-8.",
"This means that there might be problems with certain characters in file names." => "To pomeni, da se lahko pojavijo napake pri nekaterih znakih v imenih datotek.",
"We strongly suggest to install the required packages on your system to support one of the following locales: %s." => "Priporočljivo je namestiti zahtevane pakete v sistem za podporo ene izmed navedenih jezikovnih možnosti: %s",
"Internet connection not working" => "Internetna povezava ne deluje.",
"This server has no working internet connection. This means that some of the features like mounting of external storage, notifications about updates or installation of 3rd party apps don´t work. Accessing files from remote and sending of notification emails might also not work. We suggest to enable internet connection for this server if you want to have all features." => "Na voljo ni delujoče internetne povezave. To pomeni, da nekaterih možnosti, kot so priklapljanje zunanje shrambe, obveščanja o posodobitvah in nameščanje programov tretje roke ni podprto. Dostop do datotek z oddaljenih mest in pošiljanje obvestil preko elektronske pošte je verjetno še vedno mogoče. Za omogočanje vseh zmožnosti mora biti vzpostavljena tudi ustrezna internetna povezava.",
"Cron" => "Periodično opravilo",
"Last cron was executed at %s." => "Zadnje opravilo cron je bilo izvedeno ob %s.",
"Last cron was executed at %s. This is more than an hour ago, something seems wrong." => "Zadnje opravilo cron je bilo izvedeno ob %s. To je več kot uro nazaj. Nekaj je očitno narobe.",
"Cron was not executed yet!" => "Opravilo Cron še ni zagnano!",
"Execute one task with each page loaded" => "Izvedi eno nalogo z vsako naloženo stranjo.",
"cron.php is registered at a webcron service to call cron.php every 15 minutes over http." => "Datoteka cron.php je vpisana v storitvi webcron za potrditev sklica vsakih 15 minut pri povezavi preko HTTP.",
"Use system's cron service to call the cron.php file every 15 minutes." => "Uporabi storitev periodičnih opravil za klic datoteke cron.php vsakih 15 minut.",
"Sharing" => "Souporaba",
"Allow apps to use the Share API" => "Dovoli programom uporabo vmesnika API souporabe",
"Allow public uploads" => "Dovoli javno pošiljanje datotek v oblak",
"Allow resharing" => "Dovoli nadaljnjo souporabo",
"Allow users to send mail notification for shared files" => "Dovoli uporabnikom pošiljati obvestila o souporabi datotek po elektronski pošti.",
"Security" => "Varnost",
"Enforce HTTPS" => "Zahtevaj uporabo HTTPS",
"Forces the clients to connect to %s via an encrypted connection." => "Vsili povezavo odjemalca z %s preko šifrirane povezave.",
"Please connect to your %s via HTTPS to enable or disable the SSL enforcement." => "Za nastavljanje šifriranja SSL je treba vzpostaviti povezavo z mestom %s preko protokola HTTPS.",
"Email Server" => "Poštni strežnik",
"Authentication required" => "Zahtevana je overitev",
"Server address" => "Naslov strežnika",
"Port" => "Vrata",
"Credentials" => "Poverila",
"SMTP Username" => "Uporabniško ime SMTP",
"SMTP Password" => "Geslo SMTP",
"Test email settings" => "Preizkus nastavitev elektronske pošte",
"Send email" => "Pošlji elektronsko sporočilo",
"Log" => "Dnevnik",
"Log level" => "Raven beleženja",
"More" => "Več",
"Less" => "Manj",
"Version" => "Različica",
"Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>." => "Programski paket razvija <a href=\"http://ownCloud.org/contact\" target=\"_blank\">skupnost ownCloud</a>. <a href=\"https://github.com/owncloud\" target=\"_blank\">Izvorna koda</a> je objavljena pod pogoji <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Splošnega javnega dovoljenja Affero\">AGPL</abbr></a>.",
"Add your App" => "Dodaj program",
"More Apps" => "Več programov",
"Select an App" => "Izbor programa",
"Documentation:" => "Dokumentacija:",
"See application page at apps.owncloud.com" => "Obiščite spletno stran programa na apps.owncloud.com",
"See application website" => "Oglejte si spletno stran programa",
"<span class=\"licence\"></span>-licensed by <span class=\"author\"></span>" => "<span class=\"licence\"></span>-z dovoljenjem <span class=\"author\"></span>",
"All" => "Vsi",
"Administrator Documentation" => "Skrbniška dokumentacija",
"Online Documentation" => "Spletna dokumentacija",
"Forum" => "Forum",
"Bugtracker" => "Sledilnik hroščev",
"Commercial Support" => "Podpora strankam",
"Get the apps to sync your files" => "Pridobi programe za usklajevanje datotek",
"Show First Run Wizard again" => "Zaženi čarovnika prvega zagona",
"You have used <strong>%s</strong> of the available <strong>%s</strong>" => "Uporabljenega je <strong>%s</strong> od razpoložljivih <strong>%s</strong> prostora.",
"Password" => "Geslo",
"Your password was changed" => "Geslo je spremenjeno",
"Unable to change your password" => "Gesla ni mogoče spremeniti.",
"Current password" => "Trenutno geslo",
"New password" => "Novo geslo",
"Change password" => "Spremeni geslo",
"Full Name" => "Polno ime",
"Email" => "Elektronski naslov",
"Your email address" => "Osebni elektronski naslov",
"Profile picture" => "Slika profila",
"Upload new" => "Pošlji novo",
"Select new from Files" => "Izberi novo iz menija datotek",
"Remove image" => "Odstrani sliko",
"Either png or jpg. Ideally square but you will be able to crop it." => "Slika je lahko png ali jpg. Slika naj bo kvadratna, ni pa to pogoj, saj  jo bo mogoče obrezati.",
"Your avatar is provided by your original account." => "Podoba je podana v izvornem računu.",
"Cancel" => "Prekliči",
"Choose as profile image" => "Izberi kot sliko profila",
"Language" => "Jezik",
"Help translate" => "Sodelujte pri prevajanju",
"The encryption app is no longer enabled, please decrypt all your files" => "Program za šifriranje ni več omogočen. Odšifrirati je treba vse datoteke.",
"Log-in password" => "Prijavno geslo",
"Decrypt all Files" => "Odšifriraj vse datoteke",
"Login Name" => "Prijavno ime",
"Create" => "Ustvari",
"Admin Recovery Password" => "Obnovitev skrbniškega gesla",
"Enter the recovery password in order to recover the users files during password change" => "Vnesite geslo, ki omogoča obnovitev uporabniških datotek med spreminjanjem gesla",
"Add Group" => "Dodaj skupino",
"Group" => "Skupina",
"Everyone" => "Vsi",
"Admins" => "Skrbniki",
"Default Quota" => "Privzeta količinska omejitev",
"Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" => "Vnesite količinsko omejitev prostora (na primer: \"512 MB\" ali \"12 GB\")",
"Unlimited" => "Neomejeno",
"Other" => "Drugo",
"Username" => "Uporabniško ime",
"Quota" => "Količinska omejitev",
"change full name" => "Spremeni polno ime",
"set new password" => "nastavi novo geslo",
"Default" => "Privzeto"
);
$PLURAL_FORMS = "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);";

==> owncloud_7.0.13~dfsg.orig.tar.bz2: owncloud/settings/l10n/sl.php <==
<?php
$TRANSLATIONS = array(
"Invalid value supplied for %s" => "Navedena je napačna vrednost za %s",
"Saved" => "Shranjeno",
"test email settings" => "preizkusi nastavitve elektronske pošte",
"If you received this email, the settings seem to be correct." => "Če ste prejeli to sporočilo, so nastavitve pravilne.",
"A problem occurred while sending the e-mail. Please revisit your settings." => "Prišlo je do napake med pošiljanjem sporočila na elektronski naslov. Spremeniti je treba nastavitve.",
"Email sent" => "Elektronska pošta je poslana",
"Send mode" => "Način pošiljanja",
"Encryption" => "Šifriranje",
"Authentication method" => "Način overitve",
"Unable to load list from App Store" => "Ni mogoče naložiti seznama iz programskega središča",
"Authentication error" => "Napaka med overjanjem",
"Your full name has been changed." => "Vaše polno ime je spremenjeno.",
"Unable to change full name" => "Ni mogoče spremeniti polnega imena",
"Group already exists" => "Skupina že obstaja",
"Unable to add group" => "Skupine ni mogoče dodati",
"Files decrypted successfully" => "Datoteke so uspešno odšifrirane",
"Couldn't decrypt your files, please check your owncloud.log or ask your administrator" => "Datotek ni mogoče odšifrirati. Preverite dnevnik owncloud.log ali pa se posvetujte s skrbnikom.",
"Couldn't decrypt your files, check your password and try again" => "Datotek ni mogoče odšifrirati. Preverite geslo in poskusite znova.",
"Email saved" => "Elektronski naslov je shranjen",
"Invalid email" => "Neveljaven elektronski naslov",
"Unable to delete group" => "Skupine ni mogoče izbrisati",
"Unable to delete user" => "Uporabnika ni mogoče izbrisati",
"Language changed" => "Jezik je spremenjen",
"Invalid request" => "Neveljavna zahteva",
"Admins can't remove themself from the admin group" => "Skrbnikov ni mogoče odstraniti iz skupine skrbnikov (admin)",
"Unable to add user to group %s" => "Uporabnika ni mogoče dodati k skupini %s",
"Unable to remove user from group %s" => "Uporabnika ni mogoče odstraniti iz skupine %s",
"Couldn't update app." => "Programa ni mogoče posodobiti.",
"Wrong password" => "Napačno geslo",
"No user supplied" => "Ni navedenega uporabnika",
"Please provide an admin recovery password, otherwise all user data will be lost" => "Podati je treba skrbniško obnovitveno geslo, sicer bodo vsi uporabniški podatki izgubljeni.",
"Wrong admin recovery password. Please check the password and try again." => "Napačno navedeno skrbniško obnovitveno geslo. Preverite geslo in poskusite znova.",
"Back-end doesn't support password change, but the users encryption key was successfully updated." => "Hrbtišče programa ne podpira spreminjanja gesla, je pa uspešno posodobljeno uporabniško šifriranje.",
"Unable to change password" => "Ni mogoče spremeniti gesla",
"Sending..." => "Poteka pošiljanje ...",
"User Documentation" => "Uporabniška dokumentacija",
"Admin Documentation" => "Skrbniška dokumentacija",
"Update to {appversion}" => "Posodobi na {appversion}",
"Disable" => "Onemogoči",
"Enable" => "Omogoči",
"Please wait...." => "Počakajte ...",
"Error while disabling app" => "Napaka onemogočanja programa",
"Error while enabling app" => "Napaka omogočanja programa",
"Updating...." => "Poteka posodabljanje ...",
"Error while updating app" => "Prišlo je do napake med posodabljanjem programa.",
"Error" => "Napaka",
"Update" => "Posodobi",
"Updated" => "Posodobljeno",
"Uninstall" => "Odstrani namestitev",
"Select a profile picture" => "Izbor slike profila",
"Very weak password" => "Zelo šibko geslo",
"Weak password" => "Šibko geslo",
"So-so password" => "Slabo geslo",
"Good password" => "Dobro geslo",
"Strong password" => "Odlično geslo",
"Decrypting files... Please wait, this can take some time." => "Poteka odšifriranje datotek ... Opravilo je lahko dolgotrajno.",
"undo" => "razveljavi",
"Groups" => "Skupine",
"Group Admin" => "Skrbnik skupine",
"Delete" => "Izbriši",
"never" => "nikoli",
"add group" => "dodaj skupino",
"A valid username must be provided" => "Navedeno mora biti veljavno uporabniško ime",
"Error creating user" => "Napaka ustvarjanja uporabnika",
"A valid password must be provided" => "Navedeno mora biti veljavno geslo",
"Warning: Home directory for user \"{user}\" already exists" => "Opozorilo: osebna mapa uporabnika \"{user}\" že obstaja",
"__language_name__" => "Slovenščina",
"Everything (fatal issues, errors, warnings, info, debug)" => "Vse (podrobnosti, opozorila, hrošče, napake in usodne dogodke)",
"Info, warnings, errors and fatal issues" => "Podrobnosti, opozorila, napake in usodne dogodke",
"Warnings, errors and fatal issues" => "Opozorila, napake in usodne dogodke",
"Errors and fatal issues" => "Napake in usodne dogodke",
"Fatal issues only" => "Le usodne dogodke",
"None" => "Brez",
"Login" => "Prijava",
"Plain" => "Besedilno",
"NT LAN Manager" => "Upravljalnik NT LAN",
"SSL" => "SSL",
"TLS" => "TLS",
"Security Warning" => "Varnostno opozorilo",
"You are accessing %s via HTTP. We strongly suggest you configure your server to require using HTTPS instead." => "Dostop do %s poteka preko HTTP. Priporočljivo je nastaviti strežnik na privzeto uporabo varne povezave preko protokola HTTPS.",
"Your data directory and your files are probably accessible from the internet. The .htaccess file is not working. We strongly suggest that you configure your webserver in a way that the data directory is no longer accessible or you move the data directory outside the webserver document root." => "Vaša podatkovna mapa in datoteke so najverjetneje dosegljive preko interneta. Datoteka .htaccess ni ustrezno nastavljena. Priporočljivo je nastaviti spletni strežnik tako, da podatkovna mapa ni prosto dostopna. To je mogoče zagotoviti tudi tako, da je mapa premaknjena iz neustrezne korenske v podrejeno mapo .",
"Setup Warning" => "Opozorilo nastavitve",
"Your web server is not yet properly setup to allow files synchronization because the WebDAV interface seems to be broken." => "Spletni stražnik še ni ustrezno nastavljen in ne omogoča usklajevanja, saj je nastavitev WebDAV okvarjena.",
"Please double check the <a href=\"%s\">installation guides</a>." => "Preverite <a href=\"%s\">vodnike namestitve</a>.",
"Module 'fileinfo' missing" => "Manjka modul 'fileinfo'.",
"The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." => "Manjka modul PHP 'fileinfo'. Priporočljivo je omogočiti ta modul za popolno zaznavanje vrst MIME.",
"Your PHP version is outdated" => "Nameščena različica PHP je zastarela",
"Your PHP version is outdated. We strongly recommend to update to 5.3.8 or newer because older versions are known to be broken. It is possible that this installation is not working correctly." => "Nameščena različica PHP je zastarela. Priporočljivo je posodobiti namestitev na različico 5.3.8 ali novejše, saj starejše različice ne podpirajo vseh zmožnosti. Mogoče je, da namestitev ne deluje pravilno.",
"Locale not working" => "Jezikovne prilagoditve ne delujejo.",
"System locale can not be set to a one which supports UTF-8." => "Sistemskih jezikovnih nastavitev ni mogoče nastaviti na možnost, ki podpira nabor UTF-8.",
"This means that there might be problems with certain characters in file names." => "To pomeni, da se lahko pojavijo napake pri nekaterih znakih v imenih datotek.",
"We strongly suggest to install the required packages on your system to support one of the following locales: %s." => "Priporočljivo je namestiti zahtevane pakete v sistem za podporo ene izmed navedenih jezikovnih možnosti: %s",
"Internet connection not working" => "Internetna povezava ne deluje.",
"This server has no working internet connection. This means that some of the features like mounting of external storage, notifications about updates or installation of 3rd party apps don´t work. Accessing files from remote and sending of notification emails might also not work. We suggest to enable internet connection for this server if you want to have all features." => "Na voljo ni delujoče internetne povezave. To pomeni, da nekaterih možnosti, kot so priklapljanje zunanje shrambe, obveščanja o posodobitvah in nameščanje programov tretje roke ni podprto. Dostop do datotek z oddaljenih mest in pošiljanje obvestil preko elektronske pošte je verjetno še vedno mogoče. Za omogočanje vseh zmožnosti mora biti vzpostavljena tudi ustrezna internetna povezava.",
"Cron" => "Periodično opravilo",
"Last cron was executed at %s." => "Zadnje opravilo cron je bilo izvedeno ob %s.",
"Last cron was executed at %s. This is more than an hour ago, something seems wrong." => "Zadnje opravilo cron je bilo izvedeno ob %s. To je več kot uro nazaj. Nekaj je očitno narobe.",
"Cron was not executed yet!" => "Opravilo Cron še ni zagnano!",
"Execute one task with each page loaded" => "Izvedi eno nalogo z vsako naloženo stranjo.",
"cron.php is registered at a webcron service to call cron.php every 15 minutes over http." => "Datoteka cron.php je vpisana v storitvi webcron za potrditev sklica vsakih 15 minut pri povezavi preko HTTP.",
"Use system's cron service to call the cron.php file every 15 minutes." => "Uporabi storitev periodičnih opravil za klic datoteke cron.php vsakih 15 minut.",
"Sharing" => "Souporaba",
"Allow apps to use the Share API" => "Dovoli programom uporabo vmesnika API souporabe",
"Allow public uploads" => "Dovoli javno pošiljanje datotek v oblak",
"Allow resharing" => "Dovoli nadaljnjo souporabo",
"Allow users to send mail notification for shared files" => "Dovoli uporabnikom pošiljati obvestila o souporabi datotek po elektronski pošti.",
"Security" => "Varnost",
"Enforce HTTPS" => "Zahtevaj uporabo HTTPS",
"Forces the clients to connect to %s via an encrypted connection." => "Vsili povezavo odjemalca z %s preko šifrirane povezave.",
"Please connect to your %s via HTTPS to enable or disable the SSL enforcement." => "Za nastavljanje šifriranja SSL je treba vzpostaviti povezavo z mestom %s preko protokola HTTPS.",
"Email Server" => "Poštni strežnik",
"Authentication required" => "Zahtevana je overitev",
"Server address" => "Naslov strežnika",
"Port" => "Vrata",
"Credentials" => "Poverila",
"SMTP Username" => "Uporabniško ime SMTP",
"SMTP Password" => "Geslo SMTP",
"Test email settings" => "Preizkus nastavitev elektronske pošte",
"Send email" => "Pošlji elektronsko sporočilo",
"Log" => "Dnevnik",
"Log level" => "Raven beleženja",
"More" => "Več",
"Less" => "Manj",
"Version" => "Različica",
"Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>." => "Programski paket razvija <a href=\"http://ownCloud.org/contact\" target=\"_blank\">skupnost ownCloud</a>. <a href=\"https://github.com/owncloud\" target=\"_blank\">Izvorna koda</a> je objavljena pod pogoji <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Splošnega javnega dovoljenja Affero\">AGPL</abbr></a>.",
"Add your App" => "Dodaj program",
"More Apps" => "Več programov",
"Select an App" => "Izbor programa",
"Documentation:" => "Dokumentacija:",
"See application page at apps.owncloud.com" => "Obiščite spletno stran programa na apps.owncloud.com",
"See application website" => "Oglejte si spletno stran programa",
"<span class=\"licence\"></span>-licensed by <span class=\"author\"></span>" => "<span class=\"licence\"></span>-z dovoljenjem <span class=\"author\"></span>",
"All" => "Vsi",
"Administrator Documentation" => "Skrbniška dokumentacija",
"Online Documentation" => "Spletna dokumentacija",
"Forum" => "Forum",
"Bugtracker" => "Sledilnik hroščev",
"Commercial Support" => "Podpora strankam",
"Get the apps to sync your files" => "Pridobi programe za usklajevanje datotek",
"Show First Run Wizard again" => "Zaženi čarovnika prvega zagona",
"You have used <strong>%s</strong> of the available <strong>%s</strong>" => "Uporabljenega je <strong>%s</strong> od razpoložljivih <strong>%s</strong> prostora.",
"Password" => "Geslo",
"Your password was changed" => "Geslo je spremenjeno",
"Unable to change your password" => "Gesla ni mogoče spremeniti.",
"Current password" => "Trenutno geslo",
"New password" => "Novo geslo",
"Change password" => "Spremeni geslo",
"Full Name" => "Polno ime",
"Email" => "Elektronski naslov",
"Your email address" => "Osebni elektronski naslov",
"Profile picture" => "Slika profila",
"Upload new" => "Pošlji novo",
"Select new from Files" => "Izberi novo iz menija datotek",
"Remove image" => "Odstrani sliko",
"Either png or jpg. Ideally square but you will be able to crop it." => "Slika je lahko png ali jpg. Slika naj bo kvadratna, ni pa to pogoj, saj  jo bo mogoče obrezati.",
"Your avatar is provided by your original account." => "Podoba je podana v izvornem računu.",
"Cancel" => "Prekliči",
"Choose as profile image" => "Izberi kot sliko profila",
"Language" => "Jezik",
"Help translate" => "Sodelujte pri prevajanju",
"The encryption app is no longer enabled, please decrypt all your files" => "Program za šifriranje ni več omogočen. Odšifrirati je treba vse datoteke.",
"Log-in password" => "Prijavno geslo",
"Decrypt all Files" => "Odšifriraj vse datoteke",
"Login Name" => "Prijavno ime",
"Create" => "Ustvari",
"Admin Recovery Password" => "Obnovitev skrbniškega gesla",
"Enter the recovery password in order to recover the users files during password change" => "Vnesite geslo, ki omogoča obnovitev uporabniških datotek med spreminjanjem gesla",
"Add Group" => "Dodaj skupino",
"Group" => "Skupina",
"Everyone" => "Vsi",
"Admins" => "Skrbniki",
"Default Quota" => "Privzeta količinska omejitev",
"Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" => "Vnesite količinsko omejitev prostora (na primer: \"512 MB\" ali \"12 GB\")",
"Unlimited" => "Neomejeno",
"Other" => "Drugo",
"Username" => "Uporabniško ime",
"Quota" => "Količinska omejitev",
"change full name" => "Spremeni polno ime",
"set new password" => "nastavi novo geslo",
"Default" => "Privzeto",
"Connectivity Checks" => "Preverjanje povezav",
"No problems found" => "Ni zaznanih težav",
);
$PLURAL_FORMS = "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);";
